==> keycode-js-2.0.0.tgz: package/CHANGELOG.md <==
# Change Log

## [v2.0.0](https://github.com/kabirbaidhya/keycode-js/tree/v2.0.0) (2019-08-20)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v1.0.4...v2.0.0)

**Closed issues:**

- Add an example for usage with deno [\#26](https://github.com/kabirbaidhya/keycode-js/issues/26) [[example](https://github.com/kabirbaidhya/keycode-js/labels/example)] [[good first issue](https://github.com/kabirbaidhya/keycode-js/labels/good%20first%20issue)] [[help wanted](https://github.com/kabirbaidhya/keycode-js/labels/help%20wanted)]
- Make sure everything works when used in browser via a script tag [\#25](https://github.com/kabirbaidhya/keycode-js/issues/25) [[test](https://github.com/kabirbaidhya/keycode-js/labels/test)]
- Add support for deno i.e make it available on deno registry [\#21](https://github.com/kabirbaidhya/keycode-js/issues/21) [[feature](https://github.com/kabirbaidhya/keycode-js/labels/feature)]

**Improvements:**

- Test and build enhancements for node, deno and browser builds [\#28](https://github.com/kabirbaidhya/keycode-js/pull/28) [[test](https://github.com/kabirbaidhya/keycode-js/labels/test)] ([kabirbaidhya](https://github.com/kabirbaidhya))
- Include docs for usage with deno [\#27](https://github.com/kabirbaidhya/keycode-js/pull/27) [[documentation](https://github.com/kabirbaidhya/keycode-js/labels/documentation)] ([mesaugat](https://github.com/mesaugat))
- Make keycode-js compatible with deno [\#24](https://github.com/kabirbaidhya/keycode-js/pull/24) [[feature](https://github.com/kabirbaidhya/keycode-js/labels/feature)] [[refactor](https://github.com/kabirbaidhya/keycode-js/labels/refactor)] ([mesaugat](https://github.com/mesaugat))
- Change unpkg URL to next version when creating changelog [\#23](https://github.com/kabirbaidhya/keycode-js/pull/23) ([mesaugat](https://github.com/mesaugat))
- Remove deprecated options from rollup config [\#22](https://github.com/kabirbaidhya/keycode-js/pull/22) ([mesaugat](https://github.com/mesaugat))
- Run tests for both original library and the generated build  [\#20](https://github.com/kabirbaidhya/keycode-js/pull/20) [[test](https://github.com/kabirbaidhya/keycode-js/labels/test)] ([kabirbaidhya](https://github.com/kabirbaidhya))
- Use eslint-config-leapfrog for eslint configuration [\#19](https://github.com/kabirbaidhya/keycode-js/pull/19) [[dependencies](https://github.com/kabirbaidhya/keycode-js/labels/dependencies)] ([kabirbaidhya](https://github.com/kabirbaidhya))
- Remove npm-run-all and other unused dependencies [\#18](https://github.com/kabirbaidhya/keycode-js/pull/18) [[dependencies](https://github.com/kabirbaidhya/keycode-js/labels/dependencies)] ([kabirbaidhya](https://github.com/kabirbaidhya))
- Bump lodash from 4.17.10 to 4.17.14 [\#17](https://github.com/kabirbaidhya/keycode-js/pull/17) [[dependencies](https://github.com/kabirbaidhya/keycode-js/labels/dependencies)] ([dependabot[bot]](https://github.com/apps/dependabot))

## [v1.0.4](https://github.com/kabirbaidhya/keycode-js/tree/v1.0.4) (2019-01-31)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v1.0.3...v1.0.4)

**Implemented enhancements:**

- Add macOS left CMD and right CMD key code [\#15](https://github.com/kabirbaidhya/keycode-js/pull/15) [[enhancement](https://github.com/kabirbaidhya/keycode-js/labels/enhancement)] ([igogo5yo](https://github.com/igogo5yo))

## [v1.0.3](https://github.com/kabirbaidhya/keycode-js/tree/v1.0.3) (2018-10-18)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v1.0.2...v1.0.3)

## [v1.0.2](https://github.com/kabirbaidhya/keycode-js/tree/v1.0.2) (2018-08-25)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v1.0.1...v1.0.2)

## [v1.0.1](https://github.com/kabirbaidhya/keycode-js/tree/v1.0.1) (2018-08-25)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v1.0.0...v1.0.1)

## [v1.0.0](https://github.com/kabirbaidhya/keycode-js/tree/v1.0.0) (2017-12-22)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v0.0.4...v1.0.0)

**Implemented enhancements:**

- Generate type definitions \(d.ts\) file to add support for TypeScript [\#6](https://github.com/kabirbaidhya/keycode-js/issues/6) [[enhancement](https://github.com/kabirbaidhya/keycode-js/labels/enhancement)] [[feature](https://github.com/kabirbaidhya/keycode-js/labels/feature)]
- Replace webpack with rollup [\#3](https://github.com/kabirbaidhya/keycode-js/issues/3) [[enhancement](https://github.com/kabirbaidhya/keycode-js/labels/enhancement)]
- Use named export to export each key code separately [\#10](https://github.com/kabirbaidhya/keycode-js/pull/10) [[enhancement](https://github.com/kabirbaidhya/keycode-js/labels/enhancement)] [[refactor](https://github.com/kabirbaidhya/keycode-js/labels/refactor)] ([mesaugat](https://github.com/mesaugat))
- Add TypeScript declaration file [\#8](https://github.com/kabirbaidhya/keycode-js/pull/8) [[enhancement](https://github.com/kabirbaidhya/keycode-js/labels/enhancement)] ([bryanjhv](https://github.com/bryanjhv))
- Add changelog and changelog generation script [\#7](https://github.com/kabirbaidhya/keycode-js/pull/7) [[doc](https://github.com/kabirbaidhya/keycode-js/labels/doc)] [[enhancement](https://github.com/kabirbaidhya/keycode-js/labels/enhancement)] ([kabirbaidhya](https://github.com/kabirbaidhya))

**Closed issues:**

- Use ES2015 individual `export` instead of returning a wrapper object with constants. [\#5](https://github.com/kabirbaidhya/keycode-js/issues/5) [[refactor](https://github.com/kabirbaidhya/keycode-js/labels/refactor)]
- Write unit tests to test it returns all the constant keys with correct values [\#4](https://github.com/kabirbaidhya/keycode-js/issues/4) [[test](https://github.com/kabirbaidhya/keycode-js/labels/test)]
- Integrate Travis CI and add a travis badge [\#2](https://github.com/kabirbaidhya/keycode-js/issues/2)

**Improvements:**

- Major overhaul and refactor [\#12](https://github.com/kabirbaidhya/keycode-js/pull/12) [[refactor](https://github.com/kabirbaidhya/keycode-js/labels/refactor)] ([mesaugat](https://github.com/mesaugat))
- Integrate Travis CI for runnings tests [\#11](https://github.com/kabirbaidhya/keycode-js/pull/11) [[test](https://github.com/kabirbaidhya/keycode-js/labels/test)] ([kabirbaidhya](https://github.com/kabirbaidhya))
- Add tests for all the key code constants [\#9](https://github.com/kabirbaidhya/keycode-js/pull/9) [[test](https://github.com/kabirbaidhya/keycode-js/labels/test)] ([frameshft](https://github.com/frameshft))

## [v0.0.4](https://github.com/kabirbaidhya/keycode-js/tree/v0.0.4) (2016-12-05)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v0.0.3...v0.0.4)

**Implemented enhancements:**

- Add tests [\#1](https://github.com/kabirbaidhya/keycode-js/pull/1) [[enhancement](https://github.com/kabirbaidhya/keycode-js/labels/enhancement)] ([mesaugat](https://github.com/mesaugat))

## [v0.0.3](https://github.com/kabirbaidhya/keycode-js/tree/v0.0.3) (2016-10-28)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v0.0.2...v0.0.3)

## [v0.0.2](https://github.com/kabirbaidhya/keycode-js/tree/v0.0.2) (2016-04-14)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v0.0.2-0...v0.0.2)

## [v0.0.2-0](https://github.com/kabirbaidhya/keycode-js/tree/v0.0.2-0) (2016-04-05)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v0.0.1-0...v0.0.2-0)

## [v0.0.1-0](https://github.com/kabirbaidhya/keycode-js/tree/v0.0.1-0) (2016-04-04)


\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*

==> keycode-js-3.0.0.tgz: package/CHANGELOG.md <==
# Change Log

## [v3.0.0](https://github.com/kabirbaidhya/keycode-js/tree/v3.0.0) (2020-06-05)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v2.0.3...v3.0.0)

**Closed Issues**

- Missing keycodes [\#35](https://github.com/kabirbaidhya/keycode-js/issues/35) [[feature](https://github.com/kabirbaidhya/keycode-js/labels/feature)]

**Changes**

- Update missing keys and prefix key codes specific to firefox [\#36](https://github.com/kabirbaidhya/keycode-js/pull/36) [[breaking change](https://github.com/kabirbaidhya/keycode-js/labels/breaking%20change)] ([kabirbaidhya](https://github.com/kabirbaidhya))
- Update outdated dev dependencies [\#33](https://github.com/kabirbaidhya/keycode-js/pull/33) [[dependencies](https://github.com/kabirbaidhya/keycode-js/labels/dependencies)] ([kabirbaidhya](https://github.com/kabirbaidhya))

## [v2.0.3](https://github.com/kabirbaidhya/keycode-js/tree/v2.0.3) (2019-09-02)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v2.0.2...v2.0.3)

**Changes**

- Generate ES5 compatible build [\#32](https://github.com/kabirbaidhya/keycode-js/pull/32) ([inspirado](https://github.com/inspirado))

## [v2.0.2](https://github.com/kabirbaidhya/keycode-js/tree/v2.0.2) (2019-08-27)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v2.0.1...v2.0.2)

**Changes**

- Make the main build \(common js\) fully-compatible with ES5 [\#31](https://github.com/kabirbaidhya/keycode-js/pull/31) [[bugfix](https://github.com/kabirbaidhya/keycode-js/labels/bugfix)] ([kabirbaidhya](https://github.com/kabirbaidhya))

## [v2.0.1](https://github.com/kabirbaidhya/keycode-js/tree/v2.0.1) (2019-08-20)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v2.0.0...v2.0.1)

**Changes**

- Use named export for ES2015 [\#29](https://github.com/kabirbaidhya/keycode-js/pull/29) [[documentation](https://github.com/kabirbaidhya/keycode-js/labels/documentation)] ([mesaugat](https://github.com/mesaugat))

## [v2.0.0](https://github.com/kabirbaidhya/keycode-js/tree/v2.0.0) (2019-08-20)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v1.0.4...v2.0.0)

**Closed Issues**

- Add an example for usage with deno [\#26](https://github.com/kabirbaidhya/keycode-js/issues/26) [[example](https://github.com/kabirbaidhya/keycode-js/labels/example)] [[good first issue](https://github.com/kabirbaidhya/keycode-js/labels/good%20first%20issue)] [[help wanted](https://github.com/kabirbaidhya/keycode-js/labels/help%20wanted)]
- Make sure everything works when used in browser via a script tag [\#25](https://github.com/kabirbaidhya/keycode-js/issues/25) [[test](https://github.com/kabirbaidhya/keycode-js/labels/test)]
- Add support for deno i.e make it available on deno registry [\#21](https://github.com/kabirbaidhya/keycode-js/issues/21) [[feature](https://github.com/kabirbaidhya/keycode-js/labels/feature)]

**Changes**

- Test and build enhancements for node, deno and browser builds [\#28](https://github.com/kabirbaidhya/keycode-js/pull/28) [[test](https://github.com/kabirbaidhya/keycode-js/labels/test)] ([kabirbaidhya](https://github.com/kabirbaidhya))
- Include docs for usage with deno [\#27](https://github.com/kabirbaidhya/keycode-js/pull/27) [[documentation](https://github.com/kabirbaidhya/keycode-js/labels/documentation)] ([mesaugat](https://github.com/mesaugat))
- Make keycode-js compatible with deno [\#24](https://github.com/kabirbaidhya/keycode-js/pull/24) [[breaking change](https://github.com/kabirbaidhya/keycode-js/labels/breaking%20change)] [[feature](https://github.com/kabirbaidhya/keycode-js/labels/feature)] [[refactor](https://github.com/kabirbaidhya/keycode-js/labels/refactor)] ([mesaugat](https://github.com/mesaugat))
- Change unpkg URL to next version when creating changelog [\#23](https://github.com/kabirbaidhya/keycode-js/pull/23) ([mesaugat](https://github.com/mesaugat))
- Remove deprecated options from rollup config [\#22](https://github.com/kabirbaidhya/keycode-js/pull/22) ([mesaugat](https://github.com/mesaugat))
- Run tests for both original library and the generated build  [\#20](https://github.com/kabirbaidhya/keycode-js/pull/20) [[test](https://github.com/kabirbaidhya/keycode-js/labels/test)] ([kabirbaidhya](https://github.com/kabirbaidhya))
- Use eslint-config-leapfrog for eslint configuration [\#19](https://github.com/kabirbaidhya/keycode-js/pull/19) [[dependencies](https://github.com/kabirbaidhya/keycode-js/labels/dependencies)] ([kabirbaidhya](https://github.com/kabirbaidhya))
- Remove npm-run-all and other unused dependencies [\#18](https://github.com/kabirbaidhya/keycode-js/pull/18) [[dependencies](https://github.com/kabirbaidhya/keycode-js/labels/dependencies)] ([kabirbaidhya](https://github.com/kabirbaidhya))
- Bump lodash from 4.17.10 to 4.17.14 [\#17](https://github.com/kabirbaidhya/keycode-js/pull/17) [[dependencies](https://github.com/kabirbaidhya/keycode-js/labels/dependencies)] ([dependabot[bot]](https://github.com/apps/dependabot))

## [v1.0.4](https://github.com/kabirbaidhya/keycode-js/tree/v1.0.4) (2019-01-31)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v1.0.3...v1.0.4)

**Implemented enhancements:**

- Add macOS left CMD and right CMD key code [\#15](https://github.com/kabirbaidhya/keycode-js/pull/15) [[enhancement](https://github.com/kabirbaidhya/keycode-js/labels/enhancement)] ([igogo5yo](https://github.com/igogo5yo))

## [v1.0.3](https://github.com/kabirbaidhya/keycode-js/tree/v1.0.3) (2018-10-18)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v1.0.2...v1.0.3)

## [v1.0.2](https://github.com/kabirbaidhya/keycode-js/tree/v1.0.2) (2018-08-25)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v1.0.1...v1.0.2)

## [v1.0.1](https://github.com/kabirbaidhya/keycode-js/tree/v1.0.1) (2018-08-25)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v1.0.0...v1.0.1)

## [v1.0.0](https://github.com/kabirbaidhya/keycode-js/tree/v1.0.0) (2017-12-22)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v0.0.4...v1.0.0)

**Implemented enhancements:**

- Generate type definitions \(d.ts\) file to add support for TypeScript [\#6](https://github.com/kabirbaidhya/keycode-js/issues/6) [[enhancement](https://github.com/kabirbaidhya/keycode-js/labels/enhancement)] [[feature](https://github.com/kabirbaidhya/keycode-js/labels/feature)]
- Replace webpack with rollup [\#3](https://github.com/kabirbaidhya/keycode-js/issues/3) [[enhancement](https://github.com/kabirbaidhya/keycode-js/labels/enhancement)]
- Use named export to export each key code separately [\#10](https://github.com/kabirbaidhya/keycode-js/pull/10) [[enhancement](https://github.com/kabirbaidhya/keycode-js/labels/enhancement)] [[refactor](https://github.com/kabirbaidhya/keycode-js/labels/refactor)] ([mesaugat](https://github.com/mesaugat))
- Add TypeScript declaration file [\#8](https://github.com/kabirbaidhya/keycode-js/pull/8) [[enhancement](https://github.com/kabirbaidhya/keycode-js/labels/enhancement)] ([bryanjhv](https://github.com/bryanjhv))
- Add changelog and changelog generation script [\#7](https://github.com/kabirbaidhya/keycode-js/pull/7) [[doc](https://github.com/kabirbaidhya/keycode-js/labels/doc)] [[enhancement](https://github.com/kabirbaidhya/keycode-js/labels/enhancement)] ([kabirbaidhya](https://github.com/kabirbaidhya))

**Closed Issues**

- Use ES2015 individual `export` instead of returning a wrapper object with constants. [\#5](https://github.com/kabirbaidhya/keycode-js/issues/5) [[refactor](https://github.com/kabirbaidhya/keycode-js/labels/refactor)]
- Write unit tests to test it returns all the constant keys with correct values [\#4](https://github.com/kabirbaidhya/keycode-js/issues/4) [[test](https://github.com/kabirbaidhya/keycode-js/labels/test)]
- Integrate Travis CI and add a travis badge [\#2](https://github.com/kabirbaidhya/keycode-js/issues/2)

**Changes**

- Major overhaul and refactor [\#12](https://github.com/kabirbaidhya/keycode-js/pull/12) [[refactor](https://github.com/kabirbaidhya/keycode-js/labels/refactor)] ([mesaugat](https://github.com/mesaugat))
- Integrate Travis CI for runnings tests [\#11](https://github.com/kabirbaidhya/keycode-js/pull/11) [[test](https://github.com/kabirbaidhya/keycode-js/labels/test)] ([kabirbaidhya](https://github.com/kabirbaidhya))
- Add tests for all the key code constants [\#9](https://github.com/kabirbaidhya/keycode-js/pull/9) [[test](https://github.com/kabirbaidhya/keycode-js/labels/test)] ([frameshft](https://github.com/frameshft))

## [v0.0.4](https://github.com/kabirbaidhya/keycode-js/tree/v0.0.4) (2016-12-05)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v0.0.3...v0.0.4)

**Implemented enhancements:**

- Add tests [\#1](https://github.com/kabirbaidhya/keycode-js/pull/1) [[enhancement](https://github.com/kabirbaidhya/keycode-js/labels/enhancement)] ([mesaugat](https://github.com/mesaugat))

## [v0.0.3](https://github.com/kabirbaidhya/keycode-js/tree/v0.0.3) (2016-10-28)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v0.0.2...v0.0.3)

## [v0.0.2](https://github.com/kabirbaidhya/keycode-js/tree/v0.0.2) (2016-04-14)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v0.0.2-0...v0.0.2)

## [v0.0.2-0](https://github.com/kabirbaidhya/keycode-js/tree/v0.0.2-0) (2016-04-05)
[Full Changelog](https://github.com/kabirbaidhya/keycode-js/compare/v0.0.1-0...v0.0.2-0)

## [v0.0.1-0](https://github.com/kabirbaidhya/keycode-js/tree/v0.0.1-0) (2016-04-04)


\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*
